@@ -29,7 +29,7 @@ class RedditBase(PRAWBase):
         )
 
     def __getattr__(self, attribute: str) -> Any:
-        """Return the value of `attribute`."""
+        """Return the value of ``attribute``."""
         if not attribute.startswith("_") and not self._fetched:
             self._fetch()
             return getattr(self, attribute)
@@ -49,9 +49,9 @@ class RedditBase(PRAWBase):
         _fetched: bool = False,
         _str_field: bool = True,
     ):
-        """Initialize a RedditBase instance (or a subclass).
+        """Initialize a :class:`.RedditBase` instance.
 
-        :param reddit: An instance of :class:`~.Reddit`.
+        :param reddit: An instance of :class:`.Reddit`.
 
         """
         super().__init__(reddit, _data=_data)
@@ -67,6 +67,10 @@ class RedditBase(PRAWBase):
                 f"argument for the {self.STR_FIELD} parameter is not empty."
             )
 
+    def __ne__(self, other: Any) -> bool:
+        """Return whether the other instance differs from the current."""
+        return not self == other
+
     def __repr__(self) -> str:
         """Return an object initialization representation of the instance."""
         return f"{self.__class__.__name__}({self.STR_FIELD}={str(self)!r})"
@@ -75,10 +79,6 @@ class RedditBase(PRAWBase):
         """Return a string representation of the instance."""
         return getattr(self, self.STR_FIELD)
 
-    def __ne__(self, other: Any) -> bool:
-        """Return whether the other instance differs from the current."""
-        return not self == other
-
     def _fetch(self):  # pragma: no cover
         self._fetched = True
 
